#ifdef DESKTOP
#include <qapplication.h>
#else
#include <qpe/qpeapplication.h>
#endif

#include <qstring.h>

class CMessage : QObject{
  Q_OBJECT
 public:
  CMessage();
  static QString GetMessage( int id );
};
